@@ -38,15 +38,17 @@
 
 #include <glib/gi18n.h>
 #include <dbus/dbus-glib.h>
+#include <gconf/gconf-client.h>
 
-#include <libhal-gdevice.h>
-#include <libhal-gmanager.h>
-#include <libdbus-proxy.h>
+#include <hal-device.h>
+#include <hal-manager.h>
+
+#include "egg-dbus-proxy.h"
+#include "egg-debug.h"
+#include "egg-discrete.h"
 
 #include "gpm-brightness-kbd.h"
-#include "gpm-conf.h"
 #include "gpm-common.h"
-#include "egg-debug.h"
 #include "gpm-light-sensor.h"
 #include "gpm-marshal.h"
 
@@ -56,6 +58,7 @@
 
 struct GpmBrightnessKbdPrivate
 {
+	gboolean		 has_hw;
 	gboolean		 does_own_updates;	/* keys are hardwired */
 	gboolean		 does_own_dimming;	/* hardware auto-fades */
 	gboolean		 is_dimmed;
@@ -65,9 +68,9 @@ struct GpmBrightnessKbdPrivate
 	guint			 level_std_hw;
 	guint			 levels;
 	gchar			*udi;
-	GpmConf			*conf;
+	GConfClient		*conf;
 	GpmLightSensor		*sensor;
-	DbusProxy		*gproxy;
+	EggDbusProxy		*gproxy;
 };
 
 enum {
@@ -98,7 +101,7 @@ gpm_brightness_kbd_get_hw (GpmBrightnessKbd *brightness,
 	g_return_val_if_fail (brightness != NULL, FALSE);
 	g_return_val_if_fail (GPM_IS_BRIGHTNESS_KBD (brightness), FALSE);
 
-	proxy = dbus_proxy_get_proxy (brightness->priv->gproxy);
+	proxy = egg_dbus_proxy_get_proxy (brightness->priv->gproxy);
 	if (proxy == NULL) {
 		egg_warning ("not connected to HAL");
 		return FALSE;
@@ -142,7 +145,7 @@ gpm_brightness_kbd_set_hw (GpmBrightnessKbd *brightness,
 	g_return_val_if_fail (brightness != NULL, FALSE);
 	g_return_val_if_fail (GPM_IS_BRIGHTNESS_KBD (brightness), FALSE);
 
-	proxy = dbus_proxy_get_proxy (brightness->priv->gproxy);
+	proxy = egg_dbus_proxy_get_proxy (brightness->priv->gproxy);
 	if (proxy == NULL) {
 		egg_warning ("not connected to HAL");
 		return FALSE;
@@ -283,7 +286,12 @@ gpm_brightness_kbd_set_dim (GpmBrightnessKbd *brightness,
 	g_return_val_if_fail (brightness != NULL, FALSE);
 	g_return_val_if_fail (GPM_IS_BRIGHTNESS_KBD (brightness), FALSE);
 
-	level_hw = gpm_percent_to_discrete (brightness_level, brightness->priv->levels);
+	if (!brightness->priv->has_hw) {
+		egg_debug ("no hardware");
+		return FALSE;
+	}
+
+	level_hw = egg_discrete_from_percent (brightness_level, brightness->priv->levels);
 
 	/* If the current brightness_kbd is less than the dim brightness_kbd then just
 	 * use the current brightness_kbd so that we don't *increase* in brightness_kbd
@@ -316,7 +324,12 @@ gpm_brightness_kbd_set_std (GpmBrightnessKbd *brightness,
 	g_return_val_if_fail (brightness != NULL, FALSE);
 	g_return_val_if_fail (GPM_IS_BRIGHTNESS_KBD (brightness), FALSE);
 
-	level_hw = gpm_percent_to_discrete (brightness_level,
+	if (!brightness->priv->has_hw) {
+		egg_debug ("no hardware");
+		return FALSE;
+	}
+
+	level_hw = egg_discrete_from_percent (brightness_level,
 						 brightness->priv->levels);
 	brightness->priv->level_std_hw = level_hw;
 
@@ -339,6 +352,11 @@ gpm_brightness_kbd_dim (GpmBrightnessKbd *brightness)
 	g_return_val_if_fail (brightness != NULL, FALSE);
 	g_return_val_if_fail (GPM_IS_BRIGHTNESS_KBD (brightness), FALSE);
 
+	if (!brightness->priv->has_hw) {
+		egg_debug ("no hardware");
+		return FALSE;
+	}
+
 	/* check to see if we are already dimmed */
 	if (brightness->priv->is_dimmed) {
 		egg_warning ("already dim'ed");
@@ -361,6 +379,11 @@ gpm_brightness_kbd_undim (GpmBrightnessKbd *brightness)
 	g_return_val_if_fail (brightness != NULL, FALSE);
 	g_return_val_if_fail (GPM_IS_BRIGHTNESS_KBD (brightness), FALSE);
 
+	if (!brightness->priv->has_hw) {
+		egg_debug ("no hardware");
+		return FALSE;
+	}
+
 	/* check to see if we are already dimmed */
 	if (brightness->priv->is_dimmed == FALSE) {
 		egg_warning ("already undim'ed");
@@ -385,10 +408,15 @@ gpm_brightness_kbd_get (GpmBrightnessKbd *brightness,
 {
 	guint percentage;
 
+	if (!brightness->priv->has_hw) {
+		egg_debug ("no hardware");
+		return FALSE;
+	}
+
 	g_return_val_if_fail (brightness != NULL, FALSE);
 	g_return_val_if_fail (GPM_IS_BRIGHTNESS_KBD (brightness), FALSE);
 
-	percentage = gpm_discrete_to_percent (brightness->priv->current_hw,
+	percentage = egg_discrete_to_percent (brightness->priv->current_hw,
 						       brightness->priv->levels);
 	*brightness_level = percentage;
 	return TRUE;
@@ -409,6 +437,11 @@ gpm_brightness_kbd_up (GpmBrightnessKbd *brightness)
 	g_return_val_if_fail (brightness != NULL, FALSE);
 	g_return_val_if_fail (GPM_IS_BRIGHTNESS_KBD (brightness), FALSE);
 
+	if (!brightness->priv->has_hw) {
+		egg_debug ("no hardware");
+		return FALSE;
+	}
+
 	/* Do we find the new value, or set the new value */
 	if (brightness->priv->does_own_updates) {
 		gpm_brightness_kbd_get_hw (brightness, &brightness->priv->current_hw);
@@ -422,7 +455,7 @@ gpm_brightness_kbd_up (GpmBrightnessKbd *brightness)
 		gpm_brightness_kbd_set_hw (brightness, brightness->priv->current_hw + step);
 	}
 
-	percentage = gpm_discrete_to_percent (brightness->priv->current_hw,
+	percentage = egg_discrete_to_percent (brightness->priv->current_hw,
 					      brightness->priv->levels);
 	egg_debug ("emitting brightness-changed (%i)", percentage);
 	g_signal_emit (brightness, signals [BRIGHTNESS_CHANGED], 0, percentage);
@@ -445,6 +478,11 @@ gpm_brightness_kbd_down (GpmBrightnessKbd *brightness)
 	g_return_val_if_fail (brightness != NULL, FALSE);
 	g_return_val_if_fail (GPM_IS_BRIGHTNESS_KBD (brightness), FALSE);
 
+	if (!brightness->priv->has_hw) {
+		egg_debug ("no hardware");
+		return FALSE;
+	}
+
 	/* Do we find the new value, or set the new value */
 	if (brightness->priv->does_own_updates) {
 		gpm_brightness_kbd_get_hw (brightness, &brightness->priv->current_hw);
@@ -458,7 +496,7 @@ gpm_brightness_kbd_down (GpmBrightnessKbd *brightness)
 		gpm_brightness_kbd_set_hw (brightness, brightness->priv->current_hw - step);
 	}
 
-	percentage = gpm_discrete_to_percent (brightness->priv->current_hw,
+	percentage = egg_discrete_to_percent (brightness->priv->current_hw,
 					      brightness->priv->levels);
 	egg_debug ("emitting brightness-changed (%i)", percentage);
 	g_signal_emit (brightness, signals [BRIGHTNESS_CHANGED], 0, percentage);
@@ -477,18 +515,12 @@ gpm_brightness_kbd_finalize (GObject *object)
 	g_return_if_fail (GPM_IS_BRIGHTNESS_KBD (object));
 	brightness = GPM_BRIGHTNESS_KBD (object);
 
-	if (brightness->priv->udi != NULL) {
+	if (brightness->priv->udi != NULL)
 		g_free (brightness->priv->udi);
-	}
-	if (brightness->priv->gproxy != NULL) {
+	if (brightness->priv->gproxy != NULL)
 		g_object_unref (brightness->priv->gproxy);
-	}
-	if (brightness->priv->conf != NULL) {
-		g_object_unref (brightness->priv->conf);
-	}
-	if (brightness->priv->sensor != NULL) {
+	if (brightness->priv->sensor != NULL)
 		g_object_unref (brightness->priv->sensor);
-	}
 
 	g_return_if_fail (brightness->priv != NULL);
 	G_OBJECT_CLASS (gpm_brightness_kbd_parent_class)->finalize (object);
@@ -501,19 +533,16 @@ static void
 gpm_brightness_kbd_class_init (GpmBrightnessKbdClass *klass)
 {
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
-	object_class->finalize	   = gpm_brightness_kbd_finalize;
+	object_class->finalize = gpm_brightness_kbd_finalize;
 
 	signals [BRIGHTNESS_CHANGED] =
 		g_signal_new ("brightness-changed",
 			      G_TYPE_FROM_CLASS (object_class),
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (GpmBrightnessKbdClass, brightness_changed),
-			      NULL,
-			      NULL,
+			      NULL, NULL,
 			      g_cclosure_marshal_VOID__UINT,
-			      G_TYPE_NONE,
-			      1,
-			      G_TYPE_UINT);
+			      G_TYPE_NONE, 1, G_TYPE_UINT);
 
 	g_type_class_add_private (klass, sizeof (GpmBrightnessKbdPrivate));
 }
@@ -648,6 +677,11 @@ gpm_brightness_kbd_toggle (GpmBrightnessKbd *brightness)
 	g_return_val_if_fail (brightness != NULL, FALSE);
 	g_return_val_if_fail (GPM_IS_BRIGHTNESS_KBD (brightness), FALSE);
 
+	if (!brightness->priv->has_hw) {
+		egg_debug ("no hardware");
+		return FALSE;
+	}
+
 	if (brightness->priv->is_disabled == FALSE) {
 		/* go dark, that's what the user wants */
 		gpm_brightness_kbd_set_std (brightness, 0);
@@ -673,12 +707,21 @@ static void
 gpm_brightness_kbd_init (GpmBrightnessKbd *brightness)
 {
 	gchar **names;
-	HalGManager *manager;
-	HalGDevice *device;
+	HalManager *manager;
+	HalDevice *device;
+	DBusGConnection *connection;
 
 	brightness->priv = GPM_BRIGHTNESS_KBD_GET_PRIVATE (brightness);
 
-	brightness->priv->conf = gpm_conf_new ();
+	manager = hal_manager_new ();
+
+	/* save udi of kbd adapter */
+	hal_manager_find_capability (manager, "keyboard_backlight", &names, NULL);
+	if (names == NULL || names[0] == NULL) {
+		egg_warning ("No devices of capability keyboard_backlight");
+		brightness->priv->has_hw = FALSE;
+		goto out;
+	}
 
 	/* listen for ambient light changes.. if we have an ambient light sensor */
 	brightness->priv->sensor = gpm_light_sensor_new ();
@@ -687,35 +730,23 @@ gpm_brightness_kbd_init (GpmBrightnessKbd *brightness)
 				  G_CALLBACK (sensor_changed_cb), brightness);
 	}
 
-	/* save udi of kbd adapter */
-	manager = hal_gmanager_new ();
-	hal_gmanager_find_capability (manager, "keyboard_backlight", &names, NULL);
-	g_object_unref (manager);
-	if (names == NULL || names[0] == NULL) {
-		egg_warning ("No devices of capability keyboard_backlight");
-		return;
-	}
-
 	/* We only want first keyboard_backlight object (should only be one) */
 	brightness->priv->udi = g_strdup (names[0]);
-	hal_gmanager_free_capability (names);
-
 	brightness->priv->does_own_dimming = FALSE;
 	brightness->priv->does_own_updates = FALSE;
 	brightness->priv->is_disabled = FALSE;
+	brightness->priv->has_hw = TRUE;
 
 	/* get a managed proxy */
-	brightness->priv->gproxy = dbus_proxy_new ();
-	dbus_proxy_assign (brightness->priv->gproxy,
-			  DBUS_PROXY_SYSTEM,
-			  HAL_DBUS_SERVICE,
-			  brightness->priv->udi,
-			  HAL_DBUS_INTERFACE_KBD_BACKLIGHT);
+	brightness->priv->gproxy = egg_dbus_proxy_new ();
+	connection = dbus_g_bus_get (DBUS_BUS_SYSTEM, NULL);
+	egg_dbus_proxy_assign (brightness->priv->gproxy, connection, HAL_DBUS_SERVICE,
+			       brightness->priv->udi, HAL_DBUS_INTERFACE_KBD_BACKLIGHT);
 
 	/* get levels that the adapter supports -- this does not change ever */
-	device = hal_gdevice_new ();
-	hal_gdevice_set_udi (device, brightness->priv->udi);
-	hal_gdevice_get_uint (device, "keyboard_backlight.num_levels",
+	device = hal_device_new ();
+	hal_device_set_udi (device, brightness->priv->udi);
+	hal_device_get_uint (device, "keyboard_backlight.num_levels",
 			      &brightness->priv->levels, NULL);
 	g_object_unref (device);
 
@@ -732,33 +763,9 @@ gpm_brightness_kbd_init (GpmBrightnessKbd *brightness)
 
 	/* choose a start value */
 	adjust_kbd_brightness_according_to_ambient_light (brightness, TRUE);
-}
-
-/**
- * gpm_brightness_kbd_has_hw:
- *
- * Self contained function that works out if we have the hardware.
- * If not, we return FALSE and the module is unloaded.
- **/
-gboolean
-gpm_brightness_kbd_has_hw (void)
-{
-	HalGManager *manager;
-	gchar **names;
-	gboolean ret = TRUE;
-
-	/* okay, as singleton - so we don't allocate more memory */
-	manager = hal_gmanager_new ();
-	hal_gmanager_find_capability (manager, "keyboard_backlight", &names, NULL);
+out:
+	hal_manager_free_capability (names);
 	g_object_unref (manager);
-
-	/* nothing found */
-	if (names == NULL || names[0] == NULL) {
-		ret = FALSE;
-	}
-
-	hal_gmanager_free_capability (names);
-	return ret;
 }
 
 /**
@@ -769,12 +776,6 @@ GpmBrightnessKbd *
 gpm_brightness_kbd_new (void)
 {
 	GpmBrightnessKbd *brightness;
-
-	/* only load an instance of this module if we have the hardware */
-	if (gpm_brightness_kbd_has_hw () == FALSE) {
-		return NULL;
-	}
-
 	brightness = g_object_new (GPM_TYPE_BRIGHTNESS_KBD, NULL);
 	return GPM_BRIGHTNESS_KBD (brightness);
 }
