@@ -43,10 +43,12 @@
 #include <gdk/gdkx.h>
 #include <gtk/gtk.h>
 
+#include "egg-debug.h"
+#include "egg-discrete.h"
+
 #include "gpm-brightness.h"
 #include "gpm-brightness-xrandr.h"
 #include "gpm-common.h"
-#include "egg-debug.h"
 #include "gpm-marshal.h"
 
 #define GPM_BRIGHTNESS_XRANDR_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GPM_TYPE_BRIGHTNESS_XRANDR, GpmBrightnessXRandRPrivate))
@@ -101,7 +103,7 @@ gpm_brightness_xrandr_output_get_internal (GpmBrightnessXRandR *brightness, RROu
 		return FALSE;
 	}
 	if (actual_type == XA_INTEGER && nitems == 1 && actual_format == 32) {
-		memcpy (cur, prop, sizeof (guint));
+		*cur = *((int *) prop);
 		ret = TRUE;
 	}
 	XFree (prop);
@@ -130,9 +132,8 @@ gpm_brightness_xrandr_output_set_internal (GpmBrightnessXRandR *brightness, RROu
 		ret = FALSE;
 	}
 	/* we changed the hardware */
-	if (ret) {
+	if (ret)
 		brightness->priv->hw_changed = TRUE;
-	}
 	return ret;
 }
 
@@ -213,15 +214,13 @@ gpm_brightness_xrandr_output_get_percentage (GpmBrightnessXRandR *brightness, RR
 	g_return_val_if_fail (GPM_IS_BRIGHTNESS_XRANDR (brightness), FALSE);
 
 	ret = gpm_brightness_xrandr_output_get_internal (brightness, output, &cur);
-	if (!ret) {
+	if (!ret)
 		return FALSE;
-	}
 	ret = gpm_brightness_xrandr_output_get_limits (brightness, output, &min, &max);
-	if (!ret || min == max) {
+	if (!ret || min == max)
 		return FALSE;
-	}
 	egg_debug ("hard value=%i, min=%i, max=%i", cur, min, max);
-	percentage = gpm_discrete_to_percent (cur, (max-min)+1);
+	percentage = egg_discrete_to_percent (cur, (max-min)+1);
 	egg_debug ("percentage %i", percentage);
 	brightness->priv->shared_value = percentage;
 	return TRUE;
@@ -234,31 +233,26 @@ static gboolean
 gpm_brightness_xrandr_output_down (GpmBrightnessXRandR *brightness, RROutput output)
 {
 	guint cur;
-	guint step;
 	gboolean ret;
 	guint min, max;
 
 	g_return_val_if_fail (GPM_IS_BRIGHTNESS_XRANDR (brightness), FALSE);
 
 	ret = gpm_brightness_xrandr_output_get_internal (brightness, output, &cur);
-	if (!ret) {
+	if (!ret)
 		return FALSE;
-	}
 	ret = gpm_brightness_xrandr_output_get_limits (brightness, output, &min, &max);
-	if (!ret || min == max) {
+	if (!ret || min == max)
 		return FALSE;
-	}
 	egg_debug ("hard value=%i, min=%i, max=%i", cur, min, max);
 	if (cur == min) {
 		egg_debug ("already min");
 		return TRUE;
 	}
-	step = gpm_brightness_get_step ((max-min)+1);
-	if (cur < step) {
+	cur -= gpm_brightness_get_step ((max-min)+1);
+	if (cur < min) {
 		egg_debug ("truncating to %i", min);
 		cur = min;
-	} else {
-		cur -= step;
 	}
 	ret = gpm_brightness_xrandr_output_set_internal (brightness, output, cur);
 	return ret;
@@ -277,13 +271,11 @@ gpm_brightness_xrandr_output_up (GpmBrightnessXRandR *brightness, RROutput outpu
 	g_return_val_if_fail (GPM_IS_BRIGHTNESS_XRANDR (brightness), FALSE);
 
 	ret = gpm_brightness_xrandr_output_get_internal (brightness, output, &cur);
-	if (!ret) {
+	if (!ret)
 		return FALSE;
-	}
 	ret = gpm_brightness_xrandr_output_get_limits (brightness, output, &min, &max);
-	if (!ret || min == max) {
+	if (!ret || min == max)
 		return FALSE;
-	}
 	egg_debug ("hard value=%i, min=%i, max=%i", cur, min, max);
 	if (cur == max) {
 		egg_debug ("already max");
@@ -309,20 +301,17 @@ gpm_brightness_xrandr_output_set (GpmBrightnessXRandR *brightness, RROutput outp
 	guint min, max;
 	gint i;
 	gint shared_value_abs;
-	guint step;
 
 	g_return_val_if_fail (GPM_IS_BRIGHTNESS_XRANDR (brightness), FALSE);
 
 	ret = gpm_brightness_xrandr_output_get_internal (brightness, output, &cur);
-	if (!ret) {
+	if (!ret)
 		return FALSE;
-	}
 	ret = gpm_brightness_xrandr_output_get_limits (brightness, output, &min, &max);
-	if (!ret || min == max) {
+	if (!ret || min == max)
 		return FALSE;
-	}
 
-	shared_value_abs = gpm_percent_to_discrete (brightness->priv->shared_value, (max-min)+1);
+	shared_value_abs = egg_discrete_from_percent (brightness->priv->shared_value, (max-min)+1);
 	egg_debug ("percent=%i, absolute=%i", brightness->priv->shared_value, shared_value_abs);
 
 	egg_debug ("hard value=%i, min=%i, max=%i", cur, min, max);
@@ -337,36 +326,22 @@ gpm_brightness_xrandr_output_set (GpmBrightnessXRandR *brightness, RROutput outp
 
 	/* step the correct way */
 	if (cur < shared_value_abs) {
-
-		/* some adaptors have a large number of steps */
-		step = gpm_brightness_get_step (shared_value_abs - cur);
-		egg_debug ("using step of %i", step);
-
 		/* going up */
-		for (i=cur; i<=shared_value_abs; i+=step) {
+		for (i=cur; i<=shared_value_abs; i++) {
 			ret = gpm_brightness_xrandr_output_set_internal (brightness, output, i);
-			if (!ret) {
+			if (!ret)
 				break;
-			}
-			if (cur != shared_value_abs) {
+			if (cur != shared_value_abs)
 				g_usleep (1000 * GPM_BRIGHTNESS_DIM_INTERVAL);
-			}
 		}
 	} else {
-
-		/* some adaptors have a large number of steps */
-		step = gpm_brightness_get_step (cur - shared_value_abs);
-		egg_debug ("using step of %i", step);
-
 		/* going down */
-		for (i=cur; i>=shared_value_abs; i-=step) {
+		for (i=cur; i>=shared_value_abs; i--) {
 			ret = gpm_brightness_xrandr_output_set_internal (brightness, output, i);
-			if (!ret) {
+			if (!ret)
 				break;
-			}
-			if (cur != shared_value_abs) {
+			if (cur != shared_value_abs)
 				g_usleep (1000 * GPM_BRIGHTNESS_DIM_INTERVAL);
-			}
 		}
 	}
 	return TRUE;
@@ -427,9 +402,8 @@ gpm_brightness_xrandr_foreach_screen (GpmBrightnessXRandR *brightness, GpmXRandR
 		resource = (XRRScreenResources *) g_ptr_array_index (brightness->priv->resources, i);
 		egg_debug ("using resource %p", resource);
 		ret = gpm_brightness_xrandr_foreach_resource (brightness, op, resource);
-		if (ret) {
+		if (ret)
 			success_any = TRUE;
-		}
 	}
 	XSync (brightness->priv->dpy, False);
 	return success_any;
@@ -563,10 +537,11 @@ static GdkFilterReturn
 gpm_brightness_xrandr_filter_xevents (GdkXEvent *xevent, GdkEvent *event, gpointer data)
 {
 	GpmBrightnessXRandR *brightness = GPM_BRIGHTNESS_XRANDR (data);
-	egg_warning ("Event0 %p", brightness);
-	if (FALSE) {
+	if (event->type == GDK_NOTHING)
+		return GDK_FILTER_CONTINUE;
+	egg_warning ("Type %i", event->type);
+	if (FALSE)
 		gpm_brightness_xrandr_may_have_changed (brightness);
-	}
 	return GDK_FILTER_CONTINUE;
 }
 
@@ -606,9 +581,8 @@ gpm_brightness_xrandr_update_cache (GpmBrightnessXRandR *brightness)
 		egg_debug ("freeing resource %p", resource);
 		XRRFreeScreenResources (resource);
 	}
-	if (length > 0) {
+	if (length > 0)
 		g_ptr_array_remove_range (brightness->priv->resources, 0, length);
-	}
 
 	/* do for each screen */
 	display = gdk_display_get_default ();
@@ -710,9 +684,8 @@ gpm_brightness_xrandr_init (GpmBrightnessXRandR *brightness)
 			RRScreenChangeNotifyMask |
 			RROutputPropertyNotifyMask); /* <--- the only one we need, but see rh:345551 */
 	gdk_flush ();
-	if (gdk_error_trap_pop ()) {
+	if (gdk_error_trap_pop ())
 		egg_warning ("failed to select XRRSelectInput");
-	}
 
 	/* create cache of XRRScreenResources as XRRGetScreenResources() is slow */
 	gpm_brightness_xrandr_update_cache (brightness);
