@@ -25,39 +25,38 @@
 #include <stdlib.h>
 #include <glib.h>
 #include <glib/gi18n.h>
+#include <gconf/gconf-client.h>
 
-#include <libhal-gdevice.h>
-#include <libhal-gmanager.h>
+#include <hal-device.h>
+#include <hal-manager.h>
+
+#include "egg-debug.h"
+#include "egg-precision.h"
 
 #include "gpm-marshal.h"
 #include "gpm-ac-adapter.h"
 #include "gpm-common.h"
 #include "gpm-cell-array.h"
-#include "gpm-conf.h"
 #include "gpm-cell-unit.h"
 #include "gpm-cell.h"
 #include "gpm-phone.h"
 #include "gpm-control.h"
-#include "egg-debug.h"
 #include "gpm-warnings.h"
-#include "gpm-profile.h"
 
 static void     gpm_cell_array_class_init (GpmCellArrayClass *klass);
 static void     gpm_cell_array_init       (GpmCellArray      *cell_array);
 static void     gpm_cell_array_finalize   (GObject	     *object);
 
 #define GPM_CELL_ARRAY_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GPM_TYPE_CELL_ARRAY, GpmCellArrayPrivate))
-#define GPM_CELL_ARRAY_TEXT_MIN_ACCURACY	30
 #define GPM_CELL_ARRAY_TEXT_MIN_TIME		120
 #define GPM_UI_TIME_PRECISION			5*60
 
 struct GpmCellArrayPrivate
 {
-	HalGManager		*hal_manager;
+	HalManager		*hal_manager;
 	GpmCellUnit		 unit;
 	GpmAcAdapter		*ac_adapter;
-	GpmProfile		*profile;
-	GpmConf			*conf;
+	GConfClient		*conf;
 	GpmPhone		*phone;
 	GpmControl		*control;
 	GpmWarnings		*warnings;
@@ -169,7 +168,6 @@ gpm_cell_array_get_time_until_action (GpmCellArray *cell_array)
 {
 	GpmCellUnit *unit;
 	gboolean use_time_primary;
-	guint action_percentage;
 	guint action_time;
 	gint difference;
 
@@ -189,19 +187,14 @@ gpm_cell_array_get_time_until_action (GpmCellArray *cell_array)
 	}
 
 	/* calculate! */
-	gpm_conf_get_bool (cell_array->priv->conf, GPM_CONF_USE_TIME_POLICY, &use_time_primary);
+	use_time_primary = gconf_client_get_bool (cell_array->priv->conf, GPM_CONF_USE_TIME_POLICY, NULL);
 	if (use_time_primary) {
 		/* simple subtraction */
-		gpm_conf_get_uint (cell_array->priv->conf, GPM_CONF_THRESH_TIME_ACTION, &action_time);
+		action_time = gconf_client_get_int (cell_array->priv->conf, GPM_CONF_THRESH_TIME_ACTION, NULL);
 		difference = (gint) unit->time_discharge - (gint) action_time;
 	} else {
-		/* we have to work out the time for this percentage */
-		gpm_conf_get_uint (cell_array->priv->conf, GPM_CONF_THRESH_PERCENTAGE_ACTION, &action_percentage);
-		action_time = gpm_profile_get_time (cell_array->priv->profile, action_percentage, TRUE);
-		if (action_time == 0) {
-			return 0;
-		}
-		difference = (gint) unit->time_discharge - (gint) action_time;
+		/* we can't convert percentage -> time */
+		return 0;
 	}
 
 	/* if invalid, don't return junk */
@@ -343,7 +336,7 @@ gpm_cell_array_update (GpmCellArray *cell_array)
 	}
 
 	/* sanity check */
-	if (unit->is_discharging && unit->is_charging == TRUE) {
+	if (unit->is_discharging && unit->is_charging) {
 		egg_warning ("Sanity check kicked in! "
 			     "Multiple device object cannot be charging and discharging simultaneously!");
 		unit->is_charging = FALSE;
@@ -392,94 +385,34 @@ gpm_cell_array_update (GpmCellArray *cell_array)
 		}
 	}
 
-	/* We may want to use the old time remaining code.
-	 * Hopefully we can remove this in 2.19.x sometime. */
-	if (cell_array->priv->use_profile_calc &&
-	    unit->kind == GPM_CELL_UNIT_KIND_PRIMARY) {
-		egg_debug ("unit->percentage = %.1f", unit->percentage);
-		unit->time_discharge = gpm_profile_get_time (cell_array->priv->profile, unit->percentage, TRUE);
-		unit->time_charge = gpm_profile_get_time (cell_array->priv->profile, unit->percentage, FALSE);
-	} else {
-		/* We only do the "better" remaining time algorithm if the battery has rate,
-		 * i.e not a UPS, which gives it's own battery.time_charge but has no rate */
-		if (unit->rate > 0) {
-			if (unit->is_discharging) {
-				unit->time_discharge = 3600 * ((float)unit->charge_current /
-								      (float)unit->rate);
-			} else if (unit->is_charging) {
-				unit->time_charge = 3600 *
-					((float)(unit->charge_last_full - unit->charge_current) /
-					(float)unit->rate);
-			}
-		}
-		/* Check the remaining time is under a set limit, to deal with broken
-		   primary batteries rate. Fixes bug #328927 */
-		if (unit->time_charge > (100 * 60 * 60)) {
-			egg_warning ("Another sanity check kicked in! "
-				     "Remaining time cannot be > 100 hours!");
-			unit->time_charge = 0;
-		}
-		if (unit->time_discharge > (100 * 60 * 60)) {
-			egg_warning ("Another sanity check kicked in! "
-				     "Remaining time cannot be > 100 hours!");
-			unit->time_discharge = 0;
+	/* We only do the "better" remaining time algorithm if the battery has rate,
+	 * i.e not a UPS, which gives it's own battery.time_charge but has no rate */
+	if (unit->rate > 0) {
+		if (unit->is_discharging) {
+			unit->time_discharge = 3600 * ((float)unit->charge_current /
+							      (float)unit->rate);
+		} else if (unit->is_charging) {
+			unit->time_charge = 3600 *
+				((float)(unit->charge_last_full - unit->charge_current) /
+				(float)unit->rate);
 		}
 	}
+	/* Check the remaining time is under a set limit, to deal with broken
+	   primary batteries rate. Fixes bug #328927 */
+	if (unit->time_charge > (100 * 60 * 60)) {
+		egg_warning ("Another sanity check kicked in! "
+			     "Remaining time cannot be > 100 hours!");
+		unit->time_charge = 0;
+	}
+	if (unit->time_discharge > (100 * 60 * 60)) {
+		egg_warning ("Another sanity check kicked in! "
+			     "Remaining time cannot be > 100 hours!");
+		unit->time_discharge = 0;
+	}
+
 	return TRUE;
 }
 
-/**
- * gpm_cell_array_get_config_id:
- *
- * Gets an ID that represents the battery state of the system, typically
- * which will consist of all the serial numbers of primary batteries in the
- * system joined together.
- */
-static gchar *
-gpm_cell_array_get_config_id (GpmCellArray *cell_array)
-{
-	GpmCellUnit *unit;
-	GpmCell *cell;
-	gchar *id;
-	gchar *array_id = NULL;
-	gchar *new;
-	guint length;
-	guint i;
-
-	g_return_val_if_fail (GPM_IS_CELL_ARRAY (cell_array), NULL);
-
-	unit = &(cell_array->priv->unit);
-
-	/* invalid if not primary */
-	if (unit->kind != GPM_CELL_UNIT_KIND_PRIMARY) {
-		egg_warning ("only valid for primary");
-		return NULL;
-	}
-
-	length = cell_array->priv->array->len;
-	/* if we have no devices, don't try to get id */
-	if (length == 0) {
-		egg_debug ("no devices of type primary");
-		return NULL;
-	}
-
-	/* iterate thru all the devices */
-	for (i=0;i<length;i++) {
-		/* get the correct cell */
-		cell = gpm_cell_array_get_cell (cell_array, i);
-		id = gpm_cell_get_id (cell);
-		if (array_id == NULL) {
-			array_id = id;
-		} else {
-			new = g_strjoin ("-", array_id, id, NULL);
-			g_free (array_id);
-			g_free (id);
-			array_id = new;
-		}
-	}
-	return array_id;
-}
-
 /**
  * gpm_cell_array_emit_system_action:
  *
@@ -489,21 +422,12 @@ static gboolean
 gpm_cell_array_emit_system_action (GpmCellArray	   *cell_array,
 				   GpmWarningsState warnings_state)
 {
-	gfloat accuracy;
 	GpmCellUnit *unit;
 
 	g_return_val_if_fail (GPM_IS_CELL_ARRAY (cell_array), FALSE);
 
-	/* do we trust the profile enough to make a decision? */
+	/* array */
 	unit = &(cell_array->priv->unit);
-	if (unit->kind == GPM_CELL_UNIT_KIND_PRIMARY) {
-		accuracy = gpm_profile_get_accuracy_average (cell_array->priv->profile,
-							     unit->is_discharging);
-		if (accuracy < GPM_PROFILE_GOOD_TRUST) {
-			egg_debug ("profile is not accurate. Not doing policy action");
-			return FALSE;
-		}
-	}
 
 	/* we are not primary, or we are primary with a trusted profile */
 	if (warnings_state == GPM_WARNINGS_ACTION) {
@@ -606,11 +530,6 @@ gpm_cell_percent_changed_cb (GpmCell *cell, gfloat percent, GpmCellArray *cell_a
 	/* recalculate */
 	gpm_cell_array_update (cell_array);
 
-	/* provide data if we are primary. Will need profile if multibattery */
-	if (unit->kind == GPM_CELL_UNIT_KIND_PRIMARY) {
-		gpm_profile_register_percentage (cell_array->priv->profile, (guint) percent);
-	}
-
 	/* proxy to engine if different */
 	if (old_percent != unit->percentage) {
 		egg_debug ("** EMIT: percent-changed");
@@ -643,11 +562,6 @@ gpm_cell_charging_changed_cb (GpmCell *cell, gboolean charging, GpmCellArray *ce
 		cell_array->priv->warnings_state = GPM_WARNINGS_NONE;
 	}
 
-	/* provide data if we are primary. */
-	if (unit->kind == GPM_CELL_UNIT_KIND_PRIMARY) {
-		gpm_profile_register_charging (cell_array->priv->profile, charging);
-	}
-
 	/* proxy to engine */
 	egg_debug ("** EMIT: charging-changed");
 	g_signal_emit (cell_array, signals [CHARGING_CHANGED], 0, charging);
@@ -715,22 +629,22 @@ gpm_cell_array_index_device_id (GpmCellArray *cell_array, const gchar *device_id
 static gboolean
 gpm_check_device_key (GpmCellArray *cell_array, const gchar *udi, const gchar *key, const gchar *value)
 {
-	HalGDevice *device;
+	HalDevice *device;
 	gboolean ret;
 	gboolean matches = FALSE;
 	gchar *rettype;
 
 	g_return_val_if_fail (GPM_IS_CELL_ARRAY (cell_array), FALSE);
 
-	device = hal_gdevice_new ();
-	ret = hal_gdevice_set_udi (device, udi);
+	device = hal_device_new ();
+	ret = hal_device_set_udi (device, udi);
 	if (!ret) {
 		egg_warning ("failed to set UDI %s", udi);
 		return FALSE;
 	}
 
 	/* check type */
-	ret = hal_gdevice_get_string (device, key, &rettype, NULL);
+	ret = hal_device_get_string (device, key, &rettype, NULL);
 	if (!ret || rettype == NULL) {
 		egg_warning ("failed to get %s", key);
 		return FALSE;
@@ -753,7 +667,6 @@ static gboolean
 gpm_cell_array_collection_changed (GpmCellArray *cell_array)
 {
 	GpmCellUnit *unit;
-	gchar *config_id;
 	guint length;
 
 	g_return_val_if_fail (GPM_IS_CELL_ARRAY (cell_array), FALSE);
@@ -767,14 +680,6 @@ gpm_cell_array_collection_changed (GpmCellArray *cell_array)
 
 	unit = &(cell_array->priv->unit);
 
-	/* reset the profile config id if primary */
-	if (unit->kind == GPM_CELL_UNIT_KIND_PRIMARY) {
-		/* we have to use a profile ID for hot-swapping batteries */
-		config_id = gpm_cell_array_get_config_id (cell_array);
-		gpm_profile_set_config_id (cell_array->priv->profile, config_id);
-		g_free (config_id);
-	}
-
 	/* recalculate */
 	gpm_cell_array_update (cell_array);
 
@@ -867,7 +772,7 @@ gpm_cell_array_coldplug (GpmCellArray *cell_array)
 
 	/* get all the hal devices of this type */
 	error = NULL;
-	ret = hal_gmanager_find_capability (cell_array->priv->hal_manager, "battery", &device_names, &error);
+	ret = hal_manager_find_capability (cell_array->priv->hal_manager, "battery", &device_names, &error);
 	if (!ret) {
 		egg_warning ("Couldn't obtain list of batteries: %s", error->message);
 		g_error_free (error);
@@ -879,7 +784,7 @@ gpm_cell_array_coldplug (GpmCellArray *cell_array)
 		gpm_cell_array_add_device_id (cell_array, device_names[i]);
 	}
 
-	hal_gmanager_free_capability (device_names);
+	hal_manager_free_capability (device_names);
 	return TRUE;
 }
 
@@ -956,8 +861,6 @@ gpm_cell_array_get_description (GpmCellArray *cell_array)
 	gchar *charge_timestring;
 	gchar *discharge_timestring;
 	gchar *description = NULL;
-	guint accuracy;
-	guint time;
 	guint charge_time_round;
 	guint discharge_time_round;
 	GpmCellUnit *unit;
@@ -992,31 +895,17 @@ gpm_cell_array_get_description (GpmCellArray *cell_array)
 		return g_strdup_printf ("%s (%.1f%%)\n", type_desc, unit->percentage);
 	}
 
-	/* don't display the text if we are low in accuracy */
-	accuracy = gpm_profile_get_accuracy (cell_array->priv->profile, (guint) unit->percentage);
-	egg_debug ("accuracy = %i", accuracy);
-
 	/* precalculate so we don't get Unknown time remaining */
-	charge_time_round = gpm_precision_round_down (unit->time_charge, GPM_UI_TIME_PRECISION);
-	discharge_time_round = gpm_precision_round_down (unit->time_discharge, GPM_UI_TIME_PRECISION);
+	charge_time_round = egg_precision_round_down (unit->time_charge, GPM_UI_TIME_PRECISION);
+	discharge_time_round = egg_precision_round_down (unit->time_discharge, GPM_UI_TIME_PRECISION);
 
 	/* We always display "Laptop battery 16 minutes remaining" as we need
 	   to clarify what device we are refering to. For details see :
 	   http://bugzilla.gnome.org/show_bug.cgi?id=329027 */
 	if (gpm_cell_unit_is_charged (unit)) {
 
-		if (unit->kind == GPM_CELL_UNIT_KIND_PRIMARY &&
-		    accuracy > GPM_CELL_ARRAY_TEXT_MIN_ACCURACY) {
-			time = gpm_profile_get_time (cell_array->priv->profile, (guint) unit->percentage, TRUE);
-			discharge_time_round = gpm_precision_round_down (time, GPM_UI_TIME_PRECISION);
-			discharge_timestring = gpm_get_timestring (discharge_time_round);
-			description = g_strdup_printf (_("%s fully charged (%.1f%%)\nProvides %s battery runtime\n"),
-							type_desc, unit->percentage, discharge_timestring);
-			g_free (discharge_timestring);
-		} else {
-			description = g_strdup_printf (_("%s fully charged (%.1f%%)\n"),
-							type_desc, unit->percentage);
-		}
+		description = g_strdup_printf (_("%s fully charged (%.1f%%)\n"),
+						type_desc, unit->percentage);
 
 	} else if (unit->is_discharging) {
 
@@ -1034,8 +923,7 @@ gpm_cell_array_get_description (GpmCellArray *cell_array)
 	} else if (unit->is_charging) {
 
 		if (charge_time_round > GPM_CELL_ARRAY_TEXT_MIN_TIME &&
-		    discharge_time_round > GPM_CELL_ARRAY_TEXT_MIN_TIME &&
-		    accuracy > GPM_CELL_ARRAY_TEXT_MIN_ACCURACY) {
+		    discharge_time_round > GPM_CELL_ARRAY_TEXT_MIN_TIME) {
 			/* display both discharge and charge time */
 			charge_timestring = gpm_get_timestring (charge_time_round);
 			discharge_timestring = gpm_get_timestring (discharge_time_round);
@@ -1071,7 +959,7 @@ gpm_cell_array_get_description (GpmCellArray *cell_array)
  * @cell_array: This cell_array instance
  */
 static gboolean
-hal_device_removed_cb (HalGManager  *hal_manager,
+hal_device_removed_cb (HalManager  *hal_manager,
 		       const gchar  *udi,
 		       GpmCellArray *cell_array)
 {
@@ -1111,7 +999,7 @@ hal_device_removed_cb (HalGManager  *hal_manager,
  * @cell_array: This cell_array instance
  */
 static void
-hal_new_capability_cb (HalGManager  *hal_manager,
+hal_new_capability_cb (HalManager  *hal_manager,
 		       const gchar  *udi,
 		       const gchar  *capability,
 		       GpmCellArray *cell_array)
@@ -1131,23 +1019,23 @@ hal_new_capability_cb (HalGManager  *hal_manager,
  * @cell_array: This cell_array instance
  */
 static void
-hal_device_added_cb (HalGManager  *hal_manager,
+hal_device_added_cb (HalManager  *hal_manager,
 		     const gchar  *udi,
 		     GpmCellArray *cell_array)
 {
 	gboolean is_battery;
 	gboolean dummy;
-	HalGDevice *device;
+	HalDevice *device;
 
 	/* find out if the new device has capability battery
 	   this might fail for CSR as the addon is weird */
-	device = hal_gdevice_new ();
-	hal_gdevice_set_udi (device, udi);
-	hal_gdevice_query_capability (device, "battery", &is_battery, NULL);
+	device = hal_device_new ();
+	hal_device_set_udi (device, udi);
+	hal_device_query_capability (device, "battery", &is_battery, NULL);
 
 	/* try harder */
 	if (is_battery == FALSE) {
-		is_battery = hal_gdevice_get_bool (device, "battery.present", &dummy, NULL);
+		is_battery = hal_device_get_bool (device, "battery.present", &dummy, NULL);
 	}
 
 	/* if a battery, then add */
@@ -1161,14 +1049,14 @@ hal_device_added_cb (HalGManager  *hal_manager,
  * conf_key_changed_cb:
  **/
 static void
-conf_key_changed_cb (GpmConf      *conf,
+conf_key_changed_cb (GConfClient      *conf,
 		     const gchar  *key,
 		     GpmCellArray *cell_array)
 {
 	GpmCellUnit *unit;
 
 	if (strcmp (key, GPM_CONF_USE_PROFILE_TIME) == 0) {
-		gpm_conf_get_bool (conf, GPM_CONF_USE_PROFILE_TIME, &cell_array->priv->use_profile_calc);
+		cell_array->priv->use_profile_calc = gconf_client_get_bool (conf, GPM_CONF_USE_PROFILE_TIME, NULL);
 		/* recalculate */
 		gpm_cell_array_update (cell_array);
 
@@ -1255,7 +1143,7 @@ phone_device_removed_cb (GpmPhone     *phone,
  * hal_daemon_start_cb:
  **/
 static void
-hal_daemon_start_cb (HalGManager  *hal_manager,
+hal_daemon_start_cb (HalManager  *hal_manager,
 		     GpmCellArray *cell_array)
 {
 	/* coldplug all batteries back again */
@@ -1266,7 +1154,7 @@ hal_daemon_start_cb (HalGManager  *hal_manager,
  * hal_daemon_stop_cb:
  **/
 static void
-hal_daemon_stop_cb (HalGManager  *hal_manager,
+hal_daemon_stop_cb (HalManager  *hal_manager,
 		    GpmCellArray *cell_array)
 {
 	/* remove old devices */
@@ -1398,11 +1286,10 @@ gpm_cell_array_init (GpmCellArray *cell_array)
 	cell_array->priv = GPM_CELL_ARRAY_GET_PRIVATE (cell_array);
 
 	cell_array->priv->array = g_ptr_array_new ();
-	cell_array->priv->profile = gpm_profile_new ();
-	cell_array->priv->conf = gpm_conf_new ();
+	cell_array->priv->conf = gconf_client_get_default ();
 	g_signal_connect (cell_array->priv->conf, "value-changed",
 			  G_CALLBACK (conf_key_changed_cb), cell_array);
-	gpm_conf_get_bool (cell_array->priv->conf, GPM_CONF_USE_PROFILE_TIME, &cell_array->priv->use_profile_calc);
+	cell_array->priv->use_profile_calc = gconf_client_get_bool (cell_array->priv->conf, GPM_CONF_USE_PROFILE_TIME, NULL);
 
 	cell_array->priv->done_recall = FALSE;
 	cell_array->priv->done_capacity = FALSE;
@@ -1412,7 +1299,7 @@ gpm_cell_array_init (GpmCellArray *cell_array)
 
 	cell_array->priv->ac_adapter = gpm_ac_adapter_new ();
 	cell_array->priv->warnings = gpm_warnings_new ();
-	cell_array->priv->hal_manager = hal_gmanager_new ();
+	cell_array->priv->hal_manager = hal_manager_new ();
 	g_signal_connect (cell_array->priv->hal_manager, "device-added",
 			  G_CALLBACK (hal_device_added_cb), cell_array);
 	g_signal_connect (cell_array->priv->hal_manager, "device-removed",
@@ -1460,7 +1347,6 @@ gpm_cell_array_finalize (GObject *object)
 	g_object_unref (cell_array->priv->ac_adapter);
 	g_object_unref (cell_array->priv->warnings);
 	g_object_unref (cell_array->priv->hal_manager);
-	g_object_unref (cell_array->priv->profile);
 	g_object_unref (cell_array->priv->conf);
 	g_object_unref (cell_array->priv->control);
 	G_OBJECT_CLASS (gpm_cell_array_parent_class)->finalize (object);
@@ -1481,8 +1367,8 @@ gpm_cell_array_new (void)
 /***************************************************************************
  ***                          MAKE CHECK TESTS                           ***
  ***************************************************************************/
-#ifdef GPM_BUILD_TESTS
-#include "gpm-self-test.h"
+#ifdef EGG_TEST
+#include "egg-test.h"
 
 guint recall_count2 = 0;
 
@@ -1493,7 +1379,7 @@ gpm_cell_array_perhaps_recall_cb (GpmCellArray *cell_array, gchar *oem_vendor, g
 }
 
 void
-gpm_st_cell_array (GpmSelfTest *test)
+gpm_cell_test_array (EggTest *test)
 {
 	GpmCell *cell;
 	GpmCellArray *cell_array;
@@ -1502,74 +1388,74 @@ gpm_st_cell_array (GpmSelfTest *test)
 	gboolean ret;
 	guint count;
 
-	if (gpm_st_start (test, "GpmCellArray") == FALSE) {
+	if (egg_test_start (test, "GpmCellArray") == FALSE) {
 		return;
 	}
 
 	/************************************************************/
-	gpm_st_title (test, "make sure we get a non null cell array");
+	egg_test_title (test, "make sure we get a non null cell array");
 	cell_array = gpm_cell_array_new ();
 	g_signal_connect (cell_array, "perhaps-recall",
 			  G_CALLBACK (gpm_cell_array_perhaps_recall_cb), NULL);
 	if (cell_array != NULL) {
-		gpm_st_success (test, "got GpmCellArray");
+		egg_test_success (test, "got GpmCellArray");
 	} else {
-		gpm_st_failed (test, "could not get GpmCellArray");
+		egg_test_failed (test, "could not get GpmCellArray");
 	}
 
 	/************************************************************/
-	gpm_st_title (test, "make sure we get set type");
+	egg_test_title (test, "make sure we get set type");
 	ret = gpm_cell_array_set_type (cell_array, GPM_CELL_UNIT_KIND_PRIMARY);
 	if (ret) {
-		gpm_st_success (test, "set type");
+		egg_test_success (test, "set type");
 	} else {
-		gpm_st_failed (test, "could not set type");
+		egg_test_failed (test, "could not set type");
 	}
 
 	/************************************************************/
-	gpm_st_title (test, "make sure we got a single recall notice");
+	egg_test_title (test, "make sure we got a single recall notice");
 	if (recall_count2 == 0) {
-		gpm_st_warning (test, "did not get recall - install fdi!");
+		egg_test_success (test, "did not get recall - install fdi!");
 		goto out;
 	}
 	if (recall_count2 == 1) {
-		gpm_st_success (test, "got recall");
+		egg_test_success (test, "got recall");
 	} else {
-		gpm_st_failed (test, "got duplicate recall");
+		egg_test_failed (test, "got duplicate recall");
 	}
 
 	/************************************************************/
-	gpm_st_title (test, "make sure we got at least 1 cell");
+	egg_test_title (test, "make sure we got at least 1 cell");
 	count = gpm_cell_array_get_num_cells (cell_array);
 	if (count >= 1) {
-		gpm_st_success (test, "got %d cell(s)", count);
+		egg_test_success (test, "got %d cell(s)", count);
 	} else {
-		gpm_st_failed (test, "got %i cells", count);
+		egg_test_failed (test, "got %i cells", count);
 	}
 
 	/************************************************************/
-	gpm_st_title (test, "make sure we get a full description for cell array");
+	egg_test_title (test, "make sure we get a full description for cell array");
 	desc = gpm_cell_array_get_description (cell_array);
 	if (desc != NULL) {
-		gpm_st_success (test, "got description %s", desc);
+		egg_test_success (test, "got description %s", desc);
 		g_free (desc);
 	} else {
-		gpm_st_failed (test, "could not get description");
+		egg_test_failed (test, "could not get description");
 	}
 
 	/************************************************************/
-	gpm_st_title (test, "make sure we get a valid cell");
+	egg_test_title (test, "make sure we get a valid cell");
 	cell = gpm_cell_array_get_cell (cell_array, 0);
 	if (cell != NULL) {
-		gpm_st_success (test, "got correct cell");
+		egg_test_success (test, "got correct cell");
 	} else {
-		gpm_st_failed (test, "could not get correct cell");
+		egg_test_failed (test, "could not get correct cell");
 	}
 
 out:
 	g_object_unref (cell_array);
 
-	gpm_st_end (test);
+	egg_test_end (test);
 }
 
 #endif
