@@ -27,7 +27,6 @@
 #include <stdio.h>
 #include <time.h>
 #include <errno.h>
-#include <libgnomeui/gnome-client.h>
 
 #include <string.h>
 #include <sys/time.h>
@@ -41,18 +40,24 @@
 #include <dbus/dbus-glib.h>
 #include <dbus/dbus-glib-lowlevel.h>
 #include <gnome-keyring.h>
+#include <gconf/gconf-client.h>
 
-#include <libhal-gpower.h>
+#ifdef HAVE_DK_POWER
+ #include <dkp-client.h>
+#else
+ #include <hal-device-power.h>
+#endif
 
 #ifdef HAVE_POLKIT
 #include <polkit/polkit.h>
 #include <polkit-dbus/polkit-dbus.h>
 #endif
 
-#include "gpm-conf.h"
+#include "egg-debug.h"
+#include "egg-console-kit.h"
+
 #include "gpm-screensaver.h"
 #include "gpm-common.h"
-#include "egg-debug.h"
 #include "gpm-control.h"
 #include "gpm-networkmanager.h"
 
@@ -60,8 +65,12 @@
 
 struct GpmControlPrivate
 {
-	GpmConf			*conf;
-	HalGPower		*hal_power;
+	GConfClient		*conf;
+#ifdef HAVE_DK_POWER
+	DkpClient		*client;
+#else
+	HalDevicePower		*hal_device_power;
+#endif
 };
 
 enum {
@@ -85,9 +94,8 @@ GQuark
 gpm_control_error_quark (void)
 {
 	static GQuark quark = 0;
-	if (!quark) {
+	if (!quark)
 		quark = g_quark_from_static_string ("gpm_control_error");
-	}
 	return quark;
 }
 
@@ -153,29 +161,28 @@ gpm_control_check_foreground_console (GpmControl *control)
  * @control: This class instance
  * @can: If we can suspend
  *
- * Checks the HAL key power_management.can_suspend_to_ram and also
  * checks gconf to see if we are allowed to suspend this computer.
  **/
 gboolean
-gpm_control_allowed_suspend (GpmControl *control,
-			     gboolean   *can,
-			     GError    **error)
+gpm_control_allowed_suspend (GpmControl *control, gboolean *can, GError **error)
 {
 	gboolean conf_ok;
 	gboolean polkit_ok = TRUE;
-	gboolean hal_ok = FALSE;
+	gboolean hardware_ok = FALSE;
 	gboolean fg;
 	g_return_val_if_fail (can, FALSE);
 
 	*can = FALSE;
-	gpm_conf_get_bool (control->priv->conf, GPM_CONF_CAN_SUSPEND, &conf_ok);
-	hal_ok = hal_gpower_can_suspend (control->priv->hal_power);
+	conf_ok = gconf_client_get_bool (control->priv->conf, GPM_CONF_CAN_SUSPEND, NULL);
+#ifdef HAVE_DK_POWER
+	polkit_ok = gpm_control_is_user_privileged (control, "org.freedesktop.devicekit.power.suspend");
+#else
+	hardware_ok = hal_device_power_can_suspend (control->priv->hal_device_power);
 	polkit_ok = gpm_control_is_user_privileged (control, "org.freedesktop.hal.power-management.suspend");
+#endif
 	fg = gpm_control_check_foreground_console (control);
-	if (conf_ok && hal_ok && polkit_ok && fg) {
+	if (conf_ok && hardware_ok && polkit_ok && fg)
 		*can = TRUE;
-	}
-
 	return TRUE;
 }
 
@@ -188,78 +195,32 @@ gpm_control_allowed_suspend (GpmControl *control,
  * checks gconf to see if we are allowed to hibernate this computer.
  **/
 gboolean
-gpm_control_allowed_hibernate (GpmControl *control,
-			       gboolean   *can,
-			       GError    **error)
+gpm_control_allowed_hibernate (GpmControl *control, gboolean *can, GError **error)
 {
 	gboolean conf_ok;
 	gboolean polkit_ok = TRUE;
-	gboolean hal_ok = FALSE;
+	gboolean hardware_ok = FALSE;
 	gboolean fg;
 	g_return_val_if_fail (can, FALSE);
 
 	*can = FALSE;
-	gpm_conf_get_bool (control->priv->conf, GPM_CONF_CAN_HIBERNATE, &conf_ok);
-	hal_ok = hal_gpower_can_hibernate (control->priv->hal_power);
+	conf_ok = gconf_client_get_bool (control->priv->conf, GPM_CONF_CAN_HIBERNATE, NULL);
 	fg = gpm_control_check_foreground_console (control);
+#ifdef HAVE_DK_POWER
+	polkit_ok = gpm_control_is_user_privileged (control, "org.freedesktop.devicekit.power.hibernate");
+#else
+	hardware_ok = hal_device_power_can_hibernate (control->priv->hal_device_power);
 	polkit_ok = gpm_control_is_user_privileged (control, "org.freedesktop.hal.power-management.hibernate");
-	if (conf_ok && hal_ok && polkit_ok && fg) {
+#endif
+	if (conf_ok && hardware_ok && polkit_ok && fg)
 		*can = TRUE;
-	}
-	return TRUE;
-}
-
-/**
- * gpm_control_allowed_shutdown:
- * @control: This class instance
- * @can: If we can shutdown
- *
- **/
-gboolean
-gpm_control_allowed_shutdown (GpmControl *control,
-			      gboolean   *can,
-			      GError    **error)
-{
-	gboolean polkit_ok = TRUE;
-	gboolean fg;
-	g_return_val_if_fail (can, FALSE);
-	*can = FALSE;
-	fg = gpm_control_check_foreground_console (control);
-	polkit_ok = gpm_control_is_user_privileged (control, "org.freedesktop.hal.power-management.shutdown");
-	if (polkit_ok && fg) {
-		*can = TRUE;
-	}
-	return TRUE;
-}
-
-/**
- * gpm_control_allowed_reboot:
- * @control: This class instance
- * @can: If we can reboot
- *
- * Stub function -- TODO.
- **/
-gboolean
-gpm_control_allowed_reboot (GpmControl *control,
-			    gboolean   *can,
-			    GError    **error)
-{
-	gboolean polkit_ok = TRUE;
-	gboolean fg;
-	g_return_val_if_fail (can, FALSE);
-	*can = FALSE;
-	fg = gpm_control_check_foreground_console (control);
-	polkit_ok = gpm_control_is_user_privileged (control, "org.freedesktop.hal.power-management.reboot");
-	if (polkit_ok && fg) {
-		*can = TRUE;
-	}
 	return TRUE;
 }
 
+#ifndef HAVE_DK_POWER
 /* convert the HAL error to a local error */
 static void
-gpm_control_convert_hal_error (GpmControl *control,
-			       GError    **error)
+gpm_control_convert_hal_error (GpmControl *control, GError **error)
 {
 	gint code;
 	gchar *message;
@@ -286,83 +247,33 @@ gpm_control_convert_hal_error (GpmControl *control,
 	}
 	g_free (message);
 }
+#endif
 
 /**
  * gpm_control_shutdown:
  * @control: This class instance
  *
- * Shuts down the computer, saving the session if possible.
+ * Shuts down the computer
  **/
 gboolean
-gpm_control_shutdown (GpmControl *control,
-		      GError    **error)
+gpm_control_shutdown (GpmControl *control, GError **error)
 {
-	gboolean allowed;
 	gboolean ret;
-	gboolean save_session;
 
-	gpm_control_allowed_shutdown (control, &allowed, error);
-	if (allowed == FALSE) {
-		egg_warning ("Cannot shutdown");
-		g_set_error (error,
-			     GPM_CONTROL_ERROR,
-			     GPM_CONTROL_ERROR_GENERAL,
-			     "Cannot shutdown");
-		return FALSE;
-	}
-
-	gpm_conf_get_bool (control->priv->conf, GPM_CONF_SESSION_REQUEST_SAVE, &save_session);
-	/* We can set g-p-m to not save the session to avoid confusing new
-	   users. By default we save the session to preserve data. */
-	if (save_session) {
-		gnome_client_request_save (gnome_master_client (),
-					   GNOME_SAVE_GLOBAL,
-					   FALSE, GNOME_INTERACT_NONE, FALSE,  TRUE);
-	}
-
-	ret = hal_gpower_shutdown (control->priv->hal_power, error);
-	if (!ret) {
+#ifdef HAVE_DK_POWER
+	EggConsoleKit *console;
+	console = egg_console_kit_new ();
+	ret = egg_console_kit_stop (console, error);
+	g_object_unref (console);
+#else
+	ret = hal_device_power_shutdown (control->priv->hal_device_power, error);
+	if (!ret)
 		gpm_control_convert_hal_error (control, error);
-	}
+#endif
 
 	return ret;
 }
 
-/**
- * gpm_control_reboot:
- * @control: This class instance
- *
- * Reboots the computer, saving the session if possible.
- **/
-gboolean
-gpm_control_reboot (GpmControl *control,
-		    GError    **error)
-{
-	gboolean allowed;
-	gboolean save_session;
-
-	gpm_control_allowed_reboot (control, &allowed, error);
-	if (allowed == FALSE) {
-		egg_warning ("Cannot reboot");
-		g_set_error (error,
-			     GPM_CONTROL_ERROR,
-			     GPM_CONTROL_ERROR_GENERAL,
-			     "Cannot reboot");
-		return FALSE;
-	}
-
-	gpm_conf_get_bool (control->priv->conf, GPM_CONF_SESSION_REQUEST_SAVE, &save_session);
-	/* We can set g-p-m to not save the session to avoid confusing new
-	   users. By default we save the session to preserve data. */
-	if (save_session) {
-		gnome_client_request_save (gnome_master_client (),
-					   GNOME_SAVE_GLOBAL,
-					   FALSE, GNOME_INTERACT_NONE, FALSE,  TRUE);
-	}
-
-	return hal_gpower_reboot (control->priv->hal_power, error);
-}
-
 /**
  * gpm_control_get_lock_policy:
  * @control: This class instance
@@ -375,28 +286,29 @@ gpm_control_reboot (GpmControl *control,
  * Return value: TRUE if we should lock.
  **/
 gboolean
-gpm_control_get_lock_policy (GpmControl  *control,
-			     const gchar *policy)
+gpm_control_get_lock_policy (GpmControl *control, const gchar *policy)
 {
 	gboolean do_lock;
 	gboolean use_ss_setting;
 	/* This allows us to over-ride the custom lock settings set in gconf
 	   with a system default set in gnome-screensaver.
 	   See bug #331164 for all the juicy details. :-) */
-	gpm_conf_get_bool (control->priv->conf, GPM_CONF_LOCK_USE_SCREENSAVER, &use_ss_setting);
+	use_ss_setting = gconf_client_get_bool (control->priv->conf, GPM_CONF_LOCK_USE_SCREENSAVER, NULL);
 	if (use_ss_setting) {
-		gpm_conf_get_bool (control->priv->conf, GS_PREF_LOCK_ENABLED, &do_lock);
+		do_lock = gconf_client_get_bool (control->priv->conf, GS_PREF_LOCK_ENABLED, NULL);
 		egg_debug ("Using ScreenSaver settings (%i)", do_lock);
 	} else {
-		gpm_conf_get_bool (control->priv->conf, policy, &do_lock);
+		do_lock = gconf_client_get_bool (control->priv->conf, policy, NULL);
 		egg_debug ("Using custom locking settings (%i)", do_lock);
 	}
 	return do_lock;
 }
 
+/**
+ * gpm_control_suspend:
+ **/
 gboolean
-gpm_control_suspend (GpmControl *control,
-		     GError    **error)
+gpm_control_suspend (GpmControl *control, GError **error)
 {
 	gboolean allowed;
 	gboolean ret;
@@ -420,32 +332,32 @@ gpm_control_suspend (GpmControl *control,
 	}
 
 	/* we should perhaps lock keyrings when sleeping #375681 */
-	gpm_conf_get_bool (control->priv->conf, GPM_CONF_LOCK_GNOME_KEYRING_SUSPEND, &lock_gnome_keyring);
+	lock_gnome_keyring = gconf_client_get_bool (control->priv->conf, GPM_CONF_LOCK_GNOME_KEYRING_SUSPEND, NULL);
 	if (lock_gnome_keyring) {
 		keyres = gnome_keyring_lock_all_sync ();
-		if (keyres != GNOME_KEYRING_RESULT_OK) {
+		if (keyres != GNOME_KEYRING_RESULT_OK)
 			egg_warning ("could not lock keyring");
-		}
 	}
 
 	do_lock = gpm_control_get_lock_policy (control, GPM_CONF_LOCK_ON_SUSPEND);
-	if (do_lock) {
+	if (do_lock)
 		gpm_screensaver_lock (screensaver);
-	}
 
-	gpm_conf_get_bool (control->priv->conf, GPM_CONF_NETWORKMANAGER_SLEEP, &nm_sleep);
-	if (nm_sleep) {
+	nm_sleep = gconf_client_get_bool (control->priv->conf, GPM_CONF_NETWORKMANAGER_SLEEP, NULL);
+	if (nm_sleep)
 		gpm_networkmanager_sleep ();
-	}
 
 	/* Do the suspend */
 	egg_debug ("emitting sleep");
 	g_signal_emit (control, signals [SLEEP], 0, GPM_CONTROL_ACTION_SUSPEND);
 
-	ret = hal_gpower_suspend (control->priv->hal_power, 0, error);
-	if (!ret) {
+#ifdef HAVE_DK_POWER
+	ret = dkp_client_suspend (control->priv->client, error);
+#else
+	ret = hal_device_power_suspend (control->priv->hal_device_power, 0, error);
+	if (!ret)
 		gpm_control_convert_hal_error (control, error);
-	}
+#endif
 
 	egg_debug ("emitting resume");
 	g_signal_emit (control, signals [RESUME], 0, GPM_CONTROL_ACTION_SUSPEND);
@@ -455,23 +367,23 @@ gpm_control_suspend (GpmControl *control,
 		g_signal_emit (control, signals [SLEEP_FAILURE], 0, GPM_CONTROL_ACTION_SUSPEND);
 	}
 
-	if (do_lock) {
+	if (do_lock)
 		gpm_screensaver_poke (screensaver);
-	}
 
-	gpm_conf_get_bool (control->priv->conf, GPM_CONF_NETWORKMANAGER_SLEEP, &nm_sleep);
-	if (nm_sleep) {
+	nm_sleep = gconf_client_get_bool (control->priv->conf, GPM_CONF_NETWORKMANAGER_SLEEP, NULL);
+	if (nm_sleep)
 		gpm_networkmanager_wake ();
-	}
 
 	g_object_unref (screensaver);
 
 	return ret;
 }
 
+/**
+ * gpm_control_hibernate:
+ **/
 gboolean
-gpm_control_hibernate (GpmControl *control,
-		       GError    **error)
+gpm_control_hibernate (GpmControl *control, GError **error)
 {
 	gboolean allowed;
 	gboolean ret;
@@ -496,7 +408,7 @@ gpm_control_hibernate (GpmControl *control,
 	}
 
 	/* we should perhaps lock keyrings when sleeping #375681 */
-	gpm_conf_get_bool (control->priv->conf, GPM_CONF_LOCK_GNOME_KEYRING_HIBERNATE, &lock_gnome_keyring);
+	lock_gnome_keyring = gconf_client_get_bool (control->priv->conf, GPM_CONF_LOCK_GNOME_KEYRING_HIBERNATE, NULL);
 	if (lock_gnome_keyring) {
 		keyres = gnome_keyring_lock_all_sync ();
 		if (keyres != GNOME_KEYRING_RESULT_OK) {
@@ -505,22 +417,23 @@ gpm_control_hibernate (GpmControl *control,
 	}
 
 	do_lock = gpm_control_get_lock_policy (control, GPM_CONF_LOCK_ON_HIBERNATE);
-	if (do_lock) {
+	if (do_lock)
 		gpm_screensaver_lock (screensaver);
-	}
 
-	gpm_conf_get_bool (control->priv->conf, GPM_CONF_NETWORKMANAGER_SLEEP, &nm_sleep);
-	if (nm_sleep) {
+	nm_sleep = gconf_client_get_bool (control->priv->conf, GPM_CONF_NETWORKMANAGER_SLEEP, NULL);
+	if (nm_sleep)
 		gpm_networkmanager_sleep ();
-	}
 
 	egg_debug ("emitting sleep");
 	g_signal_emit (control, signals [SLEEP], 0, GPM_CONTROL_ACTION_HIBERNATE);
 
-	ret = hal_gpower_hibernate (control->priv->hal_power, error);
-	if (!ret) {
+#ifdef HAVE_DK_POWER
+	ret = dkp_client_hibernate (control->priv->client, error);
+#else
+	ret = hal_device_power_hibernate (control->priv->hal_device_power, error);
+	if (!ret)
 		gpm_control_convert_hal_error (control, error);
-	}
+#endif
 
 	egg_debug ("emitting resume");
 	g_signal_emit (control, signals [RESUME], 0, GPM_CONTROL_ACTION_HIBERNATE);
@@ -530,14 +443,12 @@ gpm_control_hibernate (GpmControl *control,
 		g_signal_emit (control, signals [SLEEP_FAILURE], 0, GPM_CONTROL_ACTION_HIBERNATE);
 	}
 
-	if (do_lock) {
+	if (do_lock)
 		gpm_screensaver_poke (screensaver);
-	}
 
-	gpm_conf_get_bool (control->priv->conf, GPM_CONF_NETWORKMANAGER_SLEEP, &nm_sleep);
-	if (nm_sleep) {
+	nm_sleep = gconf_client_get_bool (control->priv->conf, GPM_CONF_NETWORKMANAGER_SLEEP, NULL);
+	if (nm_sleep)
 		gpm_networkmanager_wake ();
-	}
 
 	g_object_unref (screensaver);
 
@@ -557,7 +468,11 @@ gpm_control_finalize (GObject *object)
 	control = GPM_CONTROL (object);
 
 	g_object_unref (control->priv->conf);
-	g_object_unref (control->priv->hal_power);
+#ifdef HAVE_DK_POWER
+	g_object_unref (control->priv->client);
+#else
+	g_object_unref (control->priv->hal_device_power);
+#endif
 
 	g_return_if_fail (control->priv != NULL);
 	G_OBJECT_CLASS (gpm_control_parent_class)->finalize (object);
@@ -621,8 +536,12 @@ gpm_control_init (GpmControl *control)
 {
 	control->priv = GPM_CONTROL_GET_PRIVATE (control);
 
-	control->priv->hal_power = hal_gpower_new ();
-	control->priv->conf = gpm_conf_new ();
+#ifdef HAVE_DK_POWER
+	control->priv->client = dkp_client_new ();
+#else
+	control->priv->hal_device_power = hal_device_power_new ();
+#endif
+	control->priv->conf = gconf_client_get_default ();
 }
 
 /**
