@@ -37,10 +37,6 @@ G_BEGIN_DECLS
 #define GS_LISTENER_PATH	"/org/gnome/ScreenSaver"
 #define GS_LISTENER_INTERFACE	"org.gnome.ScreenSaver"
 
-#define GS_PREF_DIR		"/apps/gnome-screensaver"
-#define GS_PREF_LOCK_ENABLED	GS_PREF_DIR "/lock_enabled"
-#define GS_PREF_IDLE_DELAY	GS_PREF_DIR "/idle_delay"
-
 typedef struct GpmScreensaverPrivate GpmScreensaverPrivate;
 
 typedef struct
@@ -58,7 +54,9 @@ typedef struct
 					    		 gboolean	 connected);
 	void		(* auth_request)		(GpmScreensaver	*screensaver,
 					    		 gboolean	 auth);
-	void		(* idle_changed)		(GpmScreensaver	*screensaver,
+	void		(* session_idle_changed)	(GpmScreensaver	*screensaver,
+					    		 gboolean	 is_idle);
+	void		(* powersave_idle_changed)	(GpmScreensaver	*screensaver,
 					    		 gboolean	 is_idle);
 } GpmScreensaverClass;
 
